%define name	timezone
%define epoch	6
%define version	2013g
%define release	%mkrel 2

%define tzdata_version %{version}
%define tzcode_version 2013g

# the zic(8) and zdump(8) manpages are already in man-pages
%define build_manpages 0
%ifarch %mips %arm
%define build_java 0
%else
%define build_java 1
%endif

Summary:	Timezone data
Name:		%{name}
Epoch:		%{epoch}
Version:	%{version}
Release:	%{release}
License:	GPL
Group:		System/Base
Source0:	ftp://ftp.iana.org/tz/releases/tzdata%{tzdata_version}.tar.gz
Source1:	ftp://ftp.iana.org/tz/releases/tzcode%{tzcode_version}.tar.gz
Source2:	javazic.tar.gz
Source3:	update-localtime.sh
Patch1:		tzdata-extra-tz-links.patch
Patch2:		javazic-fixup.patch
Patch3:         javazic-exclusion-fix.patch
Provides:	tzdata = %{version}-%{release}
Conflicts:     %{name} < 6:2013f-1
BuildRequires:	gawk, perl

%description
This package contains data files with rules for various timezones
around the world.

%if %{build_java}
%package java
Summary:	Timezone data for Java
Group:		System/Base
Provides:	tzdata-java = %{version}-%{release}
BuildRequires:	java-rpmbuild

%description java
This package contains timezone information for use by Java runtimes.
%endif

%prep
%setup -q -c -a 1
%patch1 -p1 -b .extra-tz-links

%if %{build_java}
mkdir javazic
tar xf %{SOURCE2} -C javazic
pushd javazic
%patch2 -p0 -b .javazic-fixup
%patch3
# Hack alert! sun.tools may be defined and installed in the
# VM. In order to guarantee that we are using IcedTea/OpenJDK
# for creating the zoneinfo files, rebase all the packages
# from "sun." to "rht.". Unfortunately, gcj does not support
# any of the -Xclasspath options, so we must go this route
# to ensure the greatest compatibility.
mv sun rht
for f in `find . -name '*.java'`; do
        sed -i -e 's:sun\.tools\.:rht.tools.:g'\
               -e 's:sun\.util\.:rht.util.:g' $f
done
popd

# Create zone.info entries for deprecated zone names (#40184)
	chmod +w zone.tab
	echo '# zone info for backward zone names' > zone.tab.new
	while read link cur old x; do
		case $link-${cur+cur}-${old+old}${x:+X} in
		Link-cur-old)
			awk -v cur="$cur" -v old="$old" \
				'!/^#/ && $3 == cur { sub(cur,old); print }' \
				zone.tab || echo ERROR ;;
		Link-*)
			echo 'Error processing backward entry for zone.tab'
			exit 1 ;;
		esac
	done < backward >> zone.tab.new
	if grep -q '^ERROR' zone.tab.new || ! cat zone.tab.new >> zone.tab; then
		echo "Error adding backward entries to zone.tab"
		exit 1
	fi
	rm -f zone.tab.new
%endif

%build

%make TZDIR=%{_datadir}/zoneinfo CFLAGS="%{optflags} -std=gnu99"

grep -v tz-art.htm tz-link.htm > tz-link.html

%if %{build_java}
pushd javazic
%{javac} -source 1.5 -target 1.5 -classpath . `find . -name \*.java`
popd
%{java} -classpath javazic/ rht.tools.javazic.Main -V %{version} \
  -d zoneinfo/java \
  africa antarctica asia australasia europe northamerica pacificnew \
  southamerica backward etcetera solar87 solar88 solar89 systemv \
  javazic/tzdata_jdk/gmt javazic/tzdata_jdk/jdk11_backward
%endif

%install
rm -rf %{buildroot}

make TOPDIR=%{buildroot}/usr \
     TZDIR=%{buildroot}%{_datadir}/zoneinfo \
     ETCDIR=%{buildroot}%{_sbindir} \
     install
rm -f %{buildroot}%{_datadir}/zoneinfo-posix
ln -s . %{buildroot}%{_datadir}/zoneinfo/posix
mv %{buildroot}%{_datadir}/zoneinfo-leaps %{buildroot}%{_datadir}/zoneinfo/right

# nuke unpackaged files
rm -f %{buildroot}%{_datadir}/zoneinfo/localtime
rm -f %{buildroot}%{_sbindir}/tzselect
rm -rf %{buildroot}/usr/{lib,man}

%if %{build_java}
cp -a zoneinfo/java %{buildroot}%{_datadir}/javazi
%endif

# install man pages
%if %{build_manpages}
mkdir -p %{buildroot}%{_mandir}/man8
for f in zic zdump; do
install -m 644 $f.8 %{buildroot}%{_mandir}/man8/
done
%endif

# install update-localtime script
mkdir -p %{buildroot}%{_sbindir}
install -m 755 %{SOURCE3} %{buildroot}%{_sbindir}/update-localtime
perl -pi -e 's|\@datadir\@|%{_datadir}|;' \
	 -e 's|\@sysconfdir\@|%{_sysconfdir}|' \
	%{buildroot}%{_sbindir}/update-localtime

%post -p %{_sbindir}/update-localtime

%pretrans
if [ ! -L %{_datadir}/zoneinfo/posix ]; then
  rm -rf %{_datadir}/zoneinfo/posix
fi

%clean
rm -rf %{buildroot}

%files
%doc README
%doc Theory
%doc tz-link.html
%{_sbindir}/zdump
%{_sbindir}/zic
%{_sbindir}/update-localtime
%if %{build_manpages}
%{_mandir}/man8/zdump.8*
%{_mandir}/man8/zic.8*
%endif
%dir %{_datadir}/zoneinfo
%{_datadir}/zoneinfo/*

%if %{build_java}
%files java
%{_datadir}/javazi
%endif


%changelog
* Tue Oct 29 2013 luigiwalser <luigiwalser> 6:2013g-2.mga3
+ Revision: 547864
- tzcode2013g
- tzdata2013g

* Fri Apr 26 2013 luigiwalser <luigiwalser> 6:2013c-1.mga3
+ Revision: 411309
- tzcode2013c
- tzdata2013c

* Thu Mar 14 2013 luigiwalser <luigiwalser> 6:2013b-1.mga3
+ Revision: 403194
- tzcode2013b
- tzdata2013b

* Mon Jan 14 2013 umeabot <umeabot> 6:2012j-2.mga3
+ Revision: 384582
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 luigiwalser <luigiwalser> 6:2012j-1.mga3
+ Revision: 338915
- tzcode2012j
- tzdata2012j

* Wed Oct 24 2012 luigiwalser <luigiwalser> 6:2012g-1.mga3
+ Revision: 309653
- tzcode2012f
- tzdata2012f
- adapt to new Makefile (based on fedora)

* Mon Sep 17 2012 luigiwalser <luigiwalser> 6:2012f-1.mga3
+ Revision: 295474
- tzcode2012f
- tzdata2012f

* Sat Sep 01 2012 luigiwalser <luigiwalser> 6:2012e-1.mga3
+ Revision: 287052
- tzcode2012e
- tzdata2012e
- update tzdata-base-0.tar.bz2 (from fedora)
- update source URLs (from opensuse)
- add hack to make version.h

* Sun Apr 15 2012 luigiwalser <luigiwalser> 6:2012c-1.mga2
+ Revision: 230826
- tzcode2012b
- tzdata2012c

* Sun Feb 26 2012 luigiwalser <luigiwalser> 6:2011n-3.mga2
+ Revision: 215055
- fix release to be newer than mga1

* Sun Dec 25 2011 gil <gil> 6:2011n-0.mga2
+ Revision: 187530
- tzdata 2011n

* Tue Nov 01 2011 dmorgan <dmorgan> 6:2011m-0.mga2
+ Revision: 160965
- New version 2011m

* Sat Oct 22 2011 gil <gil> 6:2011l-0.mga2
+ Revision: 157440
- update to 2011l

* Tue Apr 26 2011 ahmad <ahmad> 6:2011g-1.mga1
+ Revision: 91850
- Update tzdata/tzcode to 2011g

* Wed Apr 20 2011 ahmad <ahmad> 6:2011f-1.mga1
+ Revision: 89247
- Update tzcode to 2011e
- Update tzdata to 2011f
- Rediff the extra-tz-links patch

* Sun Jan 09 2011 ahmad <ahmad> 6:2010o-1.mga1
+ Revision: 4459
- drop old conflicts and old macros
- imported package timezone

